*To run this program you will run to first run the following macros:


	%macro sim_sample()		this generated data
	*macro pvalue()	        this computes p-value based on simulations




options nomprint nomlogic nonotes;

* * ********************************************************************************************;
*    Smeesters and Liu et al 2011 - "The effect of color (red versus blue) on assimilation versus contrast in prime-to-behavior effects" (JESP 2011);
* * ********************************************************************************************;



options nomprint nomlogic nonotes;
	
	* LOW;	
		%sim_sample(simtot=100000,seed=5101,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=9.487,sd=2.55,mk=1);
		%sim_sample(simtot=100000,seed=5102,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=9.487,sd=2.82,mk=2);
		%sim_sample(simtot=100000,seed=5103,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=9.487,sd=3.06,mk=3);
		%sim_sample(simtot=100000,seed=5104,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=16,m=9.487,sd=2.83,mk=4); *n=16;
		%sim_sample(simtot=100000,seed=5105,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=9.487,sd=3.03,mk=5);
		%sim_sample(simtot=100000,seed=5106,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=9.487,sd=2.66,mk=6);

		*Explanation of parameter choices: 
		   simtot=100000:   100k simulations
		   seed=5106		arbitrary seed for the random draws
		   lbound=0		    the lowest number of right answers possible is 0, so bound y by 0 from below
		   ubound=20		there are 20 questions, so 20 is the maximum possible score
		   round_y=1	    dv is # of correct answers, an integer, so rounded to 0 decimals.
		   round_m=0.01		means are reported to the 2nd decimal
		   round_sd=0.01	same
		   n=14				most samples have n=14, two exceptions are noted
		   m=9.487			the weighted average (by sample size) of the d.v. in the 6 low conditions is 9.487, see Table 1 in "Just Post It" paper
           sd=2.66			I use each condition's SD as the true sigma. Originally I had pooled the SD and use that for all conditions, effectively
							drawing from the exact same distribution for each sample. This decision (pooling SDs vs not) 
							is analogous to assuming heteroskedastic vs. homoskedastic errors.
							It is not consequential in this setting, but as I was submitting the paper I decided to use different SDs for each condition;
		

	* HIGH;
		%sim_sample(simtot=100000,seed=5107,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=11.805,sd=2.79,mk=7);
		%sim_sample(simtot=100000,seed=5108,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=11.805,sd=2.87,mk=8);
		%sim_sample(simtot=100000,seed=5109,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=13,m=11.805,sd=3.03,mk=9);*n=13;
		%sim_sample(simtot=100000,seed=5110,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=11.805,sd=2.66,mk=10); 
		%sim_sample(simtot=100000,seed=5111,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=11.805,sd=3.37,mk=11);
		%sim_sample(simtot=100000,seed=5112,lbound=0,ubound=20,round_y=1,round_m=0.01,round_sd=0.01,n=14,m=11.805,sd=2.78,mk=12);



		data s1;
			* Merge the 12 conditions into a single file
			  It has 12 columns and 100,000 rows;
			merge r1-r12 ;

		**********************************************************************************************************
		                               Overview of calculations for excessive similarity
									   =================================================

		
		*1) Compute SD(Ms) for the high SD(Mh) and the low SD(Ml) means separately
		*2) Compute the standard errors of the means in the high and low conditions, SE(Mh) and SE(Ml)
		*			2.1) Compute pooled SD for both set of conditions
					2.2) Computed pooled SE by dividing the pooled SD by the square root of average sample size 
		*3) Divide SD(Mh) and SD(Ml) by SE(Mh) and SE(Ml) respectively (those are "psi" in the paper)
		*4) Average both psis;
		**********************************************************************************************************
		
			*(1)  Compute SD(Ms) for the high SD(Mh) and the low SD(Ml) means separately;
			   	sdM_low=std(av1,av2,av3,av4,av5,av6);
				sdM_high=std(av7,av8,av9,av10,av11,av12);


			*2.1) Compute pooled SD for both set of conditions 
				  (Reference for pooling SD? see http://en.wikipedia.org/wiki/Pooled_variance);
				sdp_low = ((13*(sd1**2)+13*(sd2**2)+13*(sd3**2)+15*(sd4**2) +13*(sd5**2) +13*(sd6**2))/80)**.5;	
				sdp_high =((13*(sd7**2)+13*(sd8**2)+12*(sd9**2)+13*(sd10**2)+13*(sd11**2)+13*(sd12**2))/77)**.5;	

			*2.2) Computed pooled SE by dividing the pooled SD by the square root of average sample size ;
				se_low=sdp_low/sqrt(86/6);     *There are 83 observations across the six low conditions;
				se_high=sdp_high/sqrt(83/6);    *and 86 in the high;


			
		*3) Divide SD(Mh) and SD(Ml) by SE(Mh) and SE(Ml) respectively (those are "psi" in the paper);
				psi_low= sdM_low/se_low;
				psi_high=sdM_high/se_high;
			
		*4) Average both psis;
				psi=round(mean(psi_low,psi_high),.0001);   * Simple average of both;
				psi01=round(psi,.01);						*this is used for a graph, rounding psi to 2 decimals;



		 run;

		

		* the observed psi=.3077, how common is it?;
			%pvalue(s1,psi,.3077);
		
		

* ******************************
* DO GRAPH For Figure 4 in "Just Post It"
* ******************************;
	options notes;
	Data bins;
			do i=1 to 230;
			psi01=(i-1)/100;
			output;
			end;
	run;
	proc freq noprint data=s1;
		table psi01/out=f;
	run;
	%data_merge(bins,f,f,psi01);
	data f;
		set f;
		if count=. then count="";
	run;
	proc print;
	var psi01 count;
	run;
		
	
