*OUTLINE
*(1) LOAD FILE AND GET IT READY FOR ANALYSIS;
*(2) VERIFY MEANS;
*(3) GENERATE SIMULATIONS BOOTSTRAPPED FROM ACTUAL DATA;
*(4) SIMULATING STREAKS;
*(5) SIMULATING SAMPLING ERROR OF MEANS;
*(6) COMPARE STREAK WITH SAMPLING ERROR;

%mclear;

*(1) LOAD FILE AND GET IT READY FOR ANALYSIS;
* Load file provided by Dirk Smeesters;
	data raw;
	  infile "C:\uri\research\Fake data\Smeesters\Red Blue White\envelopes_data.txt" DSD delimiter='09'x;  
	  		  

	  input id cond score;
	  *Create dummy variable 'high' for condition predicted to have a high score, or not;
	  	  high=1;
		*THese are the low conditions, replace high=1 for high=0;
	  	if cond=1 | cond=4 | cond=6 | cond=8 | cond=9 | cond=11 then high=0;
	run;

*(2) VERIFY MEANS;
	*Sort file by condition;
	proc sort;
		by cond;
	*compute mans of d.v., score, by condition;
	proc means noprint data=raw;
	var score;
	by cond;
	output out=mverify mean= std=/autoname;
	run;
	proc print data=mverify;
	run;

*(3) GENERATE SIMULATIONS BOOTSTRAPPED FROM ACTUAL DATA;
* Each line below draws from either the High or Low conditions a sample of size 13,14 or 16
* as appropriate. 100000 such samples are drawn;
	proc surveyselect data=raw out=cond1 method = urs sampsize=14 seed=8001 outhits noprint  rep = 100000; where high=0;run; data cond1;set cond1; rename score=score1; i=mod(_N_,14); if i=0 then i=14;run;
	proc surveyselect data=raw out=cond2 method = urs sampsize=14 seed=8002 outhits noprint  rep = 100000; where high=1;run;data cond2;set cond2; rename score=score2; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond3 method = urs sampsize=14 seed=8003 outhits noprint  rep = 100000; where high=1;run;data cond3;set cond3; rename score=score3; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond4 method = urs sampsize=16 seed=8004 outhits noprint  rep = 100000; where high=0;run;data cond4;set cond4; rename score=score4; i=mod(_N_,16);if i=0 then i=16;run;
	proc surveyselect data=raw out=cond5 method = urs sampsize=14 seed=8005 outhits noprint  rep = 100000; where high=1;run;data cond5;set cond5; rename score=score5; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond6 method = urs sampsize=14 seed=8006 outhits noprint  rep = 100000; where high=0;run;data cond6;set cond6; rename score=score6; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond7 method = urs sampsize=13 seed=8007 outhits noprint  rep = 100000; where high=1;run;data cond7;set cond7; rename score=score7; i=mod(_N_,13);if i=0 then i=13;run;
	proc surveyselect data=raw out=cond8 method = urs sampsize=14 seed=8008 outhits noprint  rep = 100000; where high=0;run;data cond8;set cond8; rename score=score8; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond9 method = urs sampsize=14 seed=8009  outhits noprint  rep = 100000; where high=0;run;data cond9;set cond9; rename score=score9; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond10 method = urs sampsize=14 seed=8010 outhits noprint  rep = 100000; where high=1;run;data cond10;set cond10; rename score=score10; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond11 method = urs sampsize=14 seed=8011 outhits noprint  rep = 100000; where high=0;run;data cond11;set cond11; rename score=score11; i=mod(_N_,14);if i=0 then i=14;run;
	proc surveyselect data=raw out=cond12 method = urs sampsize=14 seed=8012 outhits noprint  rep = 100000; where high=1;run;data cond12;set cond12; rename score=score12; i=mod(_N_,14);if i=0 then i=14;run;
	
*(3.1) SAVE DATA SO THAT I CAN RE-USE SAME SIMULATIONS;
	 %macro savesim;
			%do i=1 %to 12;
					data "C:\uri\research\Fake data\(public) Too similar\Data\bootstrapped_envelopes_cond&i";
						set cond&i;
					run;
			%end;
	%mend;
	%savesim;


*(4) ** SIMULATING STREAKS;
	*(4.1) A macro to stack up all 12 conditions into a single file

		*Convert the 12 scores into a single score, the put file vertically;
			%macro v;
				%do i=1 %to 12;
					data cond&i;
						set cond&i;
						rename score&i =score;
						cond=&i;
					run;
				%end;

				data v;
					set 
				%do i=1 %to 12;
				    cond&i
				%end;
					;
				run;
			%mend;
		*now run the macro;
			%v;

	*4.2) Count each score per condition per replication;
			*note: replicate is a variable that indicates the sample id, it ranges from 1 to 100,000;
			*Count is done per condition and per replication sample, so we need to sort first;
			proc sort data=v;
				by replicate cond;
			run;
			proc freq data=v noprint;
				table score/out=f;
				by replicate cond;
			run;

	*4.3) Find the longest streak per condition per replication;	
			proc means noprint data=f;
			var count;
			output out=m max(count)=streak;
			by replicate cond;
			run;
			*clean output file;
				data m;
				set m;
				drop _TYPE_ _FREQ_;
				run;

			* convert to table format;
				proc transpose data=m out=tm prefix=cond;
				var streak;
				by replicate;
				id cond;
				run;
	*4.4) Sum streaks to create streak index;
			data tm;
				set tm;
				*streak_sum is the streak index, the sum of the largest sterak in each condition;
				streak_sum=cond1+cond2+cond3+cond4+cond5+cond6+cond7+cond8+cond9+cond10+cond11+cond12;
			run;
	*4.5) Now look at the CDF of streak index to compare with that from the paper;
			*the output of this command is used to generate the streak figure in the note;
			proc freq data=tm;
				table streak_sum;
			run;
			

*(5) ** SIMULATING SAMPLING ERROR OF MEANS;

*(5.1) Load the same simualted samples used for streaks;
 			%macro loadsim;
			%do i=1 %to 12;
					data cond&i;
						set "C:\uri\research\Fake data\(public) Too similar\Data\bootstrapped_envelopes_cond&i";
					run;
			%end;
			%mend;
			%loadsim;

*(5.2) Merge (rather than stack) the conditions horizontally;
	data sim;
		merge cond1-cond12;
		by replicate i;
		drop high Numberhits cond id;
	run;

*(5.3) Compute the means of each condition in each replication;
	proc means data=sim noprint;
		var score1-score12;
		by replicate;
		output out=m mean= std=/autoname ;
	run;

	
	*rename to make it parallel in naming structure to Monte Carlo with normal distribution;
	data m2;
		set m;
		drop _TYPE_ _FREQ_ ;
			rename 
			score1_mean=av1 score2_mean=av2  score3_mean=av3  score4_mean=av4   score5_mean=av5    score6_mean=av6  
			score7_mean=av7 score8_mean=av8  score9_mean=av9  score10_mean=av10 score11_mean=av11  score12_mean=av12  
			score1_stddev=sd1 score2_stddev=sd2  score3_stddev=sd3  score4_stddev=sd4   score5_stddev=sd5    score6_stddev=sd6  
			score7_stddev=sd7 score8_stddev=sd8  score9_stddev=sd9  score10_stddev=sd10 score11_stddev=sd11  score12_stddev=sd12;  
	run;

	*compute psi;
		data m2;
			set m2;
		*pooled SD;
					sdp_low = ((13*(sd1**2)+15*(sd4**2)+13*(sd6**2)+15*(sd8**2) +13*(sd9**2) +13*(sd11**2))/80)**.5;	
					sdp_high =((13*(sd2**2)+13*(sd3**2)+13*(sd5**2)+12*(sd7**2)+13*(sd10**2)+13*(sd12**2))/77)**.5;	
				*Average SE based on SDpooled;
					se_low=sdp_low/sqrt(86/6);
					se_high=sdp_low/sqrt(83/6);

				*SDMs;
				   	sdM_low=std(av1,av4,av6,av8,av9,av11);
					sdM_high=std(av2,av3,av5,av7,av10,av12);

				*SDM/SE;
					psi_low= sdM_low/se_low;
					psi_high=sdM_high/se_high;
				
				*PSi;
					psi=round(mean(psi_low,psi_high),.0001);
					psi01=round(psi,.01);

		run;
		
		proc print data=m2 (obs=1);
		run;
		%pvalue(m2,psi,.3081);

		

*(6) COMPARE STREAK WITH SAMPLING ERROR;

*(6.1) Merge streak and sammpling error results;
	*Create file SE for the sampling error, keeps only key variables;
	data se;
		set m2;
		keep replicate psi;
	run;
	*Create file streak for the streak analysis, keeps only key variables;
	data streak;
		set tm;
		keep replicate streak_sum;
	run;

	*Merge both files;
	%data_merge(se,streak,se_streak,replicate);
		*this is a custom macro I use for merging files, you can replace for a standard merge
		where we merge by variable replicate;

*(6.2) Compute correlation of the two;
		proc corr;
		var psi streak_sum;
		run;

*(6.3) See how many simulations have both low sdm and streak sum;
	data se_streak;
		set se_streak;
		if streak_sum<=33 & psi<=.3081 then hit=1; else hit=0;
		*hit=1 means a simulation is as low in sampling error and streak index as JESP2011;
	run;
	proc freq;
	table hit;
	run;
	
	
