*THIS IS THE MAIN MACRO USED TO SIMULATE SAMPLES IN THE "JUST POST IT" PAPER (http://papers.ssrn.com/sol3/papers.cfm?abstract_id=2114571)




	********************************************************************************************
	*SYNTAX:
		%sim_sample(simtot,lbound,ubound,round_y,round_m,round_sd,n,m,sd,mk)
        seed:    used to always draw the same random numbers
		simtot:  total number of simulations (e.g., 10000)
		lbound:  lower bound on dependent variable (e.g., 1 for a 1-9 likert scale)
		ubound:  upper bound on dependent variable (e.g., 9 for a 1-9 likert scale)
		round_y: how much is the dv rounded (e.g., 1 for a single item likert, .5 for the average of two, 
					.01 for something measured with an instrument providing measurement up to 2 decimals)
		round_m: how much is the reported mean rounded (e.g., ".1" for means reported as 3.1, 2.4
		round_sd: same for the standard deviation reported
		n:	     simulated sample size
		m:	     simulated true mean
		sd:	     simulated true sd
		mk:	     meaningless counter used to name files with results and the aggregate across them;
	********************************************************************************************

	*The result of this simulation is a file called r&mk which contains three columns and &simtot rows;
	*The three columns contain the simulation number (simK) average (av&mk) and standard deviation (sd&mk);



%macro sim_sample(seed,simtot,lbound,ubound,round_y,round_m,round_sd,n,m,sd,mk);


		*OVERVIEW:
			* Generate Normal(0,1)
			* Multiply by &SD so that it has the desired variance
			* Add &m so that it has the desried mean
			* Round it so that the random drawn has the  desired number of decimals 
					(e.g., for a 1-9 likert scale, it would be rounded to 0 decimals);
			* use min/max to bound from below and above 
					(e.g., for a 1-9 likert scale, it would be bounded by 1 and 9);





	*start clock (used to provide feedback on time to complete simulations);
		%let a=%sysfunc(time(),time8.) ;

	*Generate single file with all simulations;
		DATA sim; drop obs;
			do obs=1 to %eval(&simtot*&n);
			y=min(max(round(normal(&seed)*&sd + &m,&round_y),&lbound),&ubound);
			output;end;  
		run;
	* dataset is empty righ tnow, we now add the simulated variable &y;


	* Add variable counting the observvation number within each simulation, and numbering the simulations themselves;
			data sim;
				set sim;
				simulation=int((_N_-1)/(&n)) +1;
				k=_N_-(simulation-1)*(&n)  ;
			run;

* Compute means and SDs for each simulated sample;
		proc means noprint;
			var y;
			by simulation;
			output out=m;
		run;

*NOte: what follows is a bit innefficient as I process means and SDs separately, but it makes debugging easier;


*Store SDs in one file;
		data sd;
			set m;
			if _STAT_="STD";
			keep y simulation;
			y=round(y,&round_m);  *Here I am rounding the mean to the precision in the paper;
			rename y= sd&mk;
		run;
		*Sore means in another;
		data av;
			set m;
			if _STAT_="MEAN";
			y=round(y,&round_sd);  *Here I am rounding the SD to the precision in the paper;
			keep y simulation;
			rename y= av&mk;
		run;



		*MErge means and SDs;
		data r&mk;
			merge av sd;
			by simulation;
		run;


		

%put START: &a;

*This outputs in the log how long it took to run the macro;
%put FINALIZO: %sysfunc(time(),time8.) ;
%mend;
